@@ -1,7 +1,6 @@
 import asyncio
 from typing import TYPE_CHECKING, Union
 
-from IPython.terminal.shortcuts import previous_history_or_previous_completion
 from loguru import logger
 
 from sparrow import ConcurrentRequester
@@ -33,8 +32,7 @@ class OpenAIClient:
         self._base_url = base_url.rstrip("/")
         self._api_key = api_key
 
-    async def wrap_to_request_params(self, messages: list, model: str, max_tokens=None, meta=None, preprocess_msg=False,
-                                     **kwargs):
+    async def wrap_to_request_params(self, messages: list, model: str, max_tokens=None, meta=None, preprocess_msg=False, **kwargs):
         if preprocess_msg:
             messages = await messages_preprocess(messages, preprocess_msg=preprocess_msg)
         request_params = {
